import * as React from 'react';
import { RcFile as OriRcFile, UploadRequestOption as RcCustomRequestOptions, UploadProps as RcUploadProps } from 'rc-upload/lib/interface';
export interface RcFile extends OriRcFile {
    readonly lastModifiedDate: Date;
}
export type UploadFileStatus = 'error' | 'success' | 'done' | 'uploading' | 'removed';
export interface HttpRequestHeader {
    [key: string]: string;
}
export interface UploadFile<T = any> {
    uid: string;
    size?: number;
    name: string;
    fileName?: string;
    lastModified?: number;
    lastModifiedDate?: Date;
    url?: string;
    status?: UploadFileStatus;
    percent?: number;
    thumbUrl?: string;
    originFileObj?: RcFile;
    response?: T;
    error?: any;
    linkProps?: any;
    type?: string;
    xhr?: T;
    preview?: string;
    disableRemove?: boolean;
}
export interface UploadChangeParam<T extends object = UploadFile> {
    file: T;
    fileList: UploadFile[];
    event?: {
        percent: number;
    };
}
export interface ShowUploadListInterface {
    showRemoveIcon?: boolean;
    showPreviewIcon?: boolean;
    removeIcon?: React.ReactNode | ((file: UploadFile) => React.ReactNode);
}
export type UploadType = 'select' | 'form-upload';
export type UploadListType = 'text' | 'picture';
export type ItemRender<T = any> = (originNode: React.ReactElement, file: UploadFile, fileList?: Array<UploadFile<T>>) => React.ReactNode;
type PreviewFileHandler = (file: File | Blob) => PromiseLike<string>;
type TransformFileHandler = (file: RcFile) => string | Blob | File | PromiseLike<string | Blob | File>;
export interface UploadProps<T = any> {
    /**
     * @description 标签名，在form表单中，请使用该字段来替代Form.Item的label
     */
    label?: React.ReactNode;
    /**
     * @description upload类型，分为 ‘select’(单独使用，不放在form表单中)与'form-upload'(表单中使用)
     */
    type?: UploadType;
    /**
     * @description 发送到后台的name名称，放到form中可以直接使用Form.Item的name
     */
    name?: string;
    /**
     * @description 默认的上传好的文件列表，如果在表单中则无需设定该字段，使用表单的initValue
     */
    defaultFileList?: Array<UploadFile<T>>;
    /**
     * @description 已经上传的文件列表（受控），使用此参数时，如果遇到 onChange 只调用一次的问题，请参考 #2423
     */
    fileList?: Array<UploadFile<T>>;
    /**
     * @description 用于在表单中接受表单传来的initValue
     */
    value?: Array<UploadFile<T>>;
    /**
     * @description 上传的地址
     */
    action?: string | ((file: RcFile) => string) | ((file: RcFile) => PromiseLike<string>);
    /**
     * @description 支持上传文件夹（caniuse）
     */
    directory?: boolean;
    /**
     * @description 上传所需额外参数或返回上传额外参数的方法
     */
    data?: RcUploadProps['data'];
    /**
     * @description 上传请求的 http method
     */
    method?: 'POST' | 'PUT' | 'PATCH' | 'post' | 'put' | 'patch';
    /**
     * @description 设置上传的请求头部，IE10 以上有效
     */
    headers?: HttpRequestHeader;
    /**
     * @description 是否展示文件列表, 可设为一个对象，用于单独设定 showPreviewIcon, showRemoveIcon, showDownloadIcon, removeIcon 和 downloadIcon
     */
    showUploadList?: boolean | ShowUploadListInterface;
    /**
     * @description 是否支持多选文件，ie10+ 支持。开启后按住 ctrl 可选择多个文件
     */
    multiple?: boolean;
    /**
     * @description 接受上传的文件类型, 详见 input accept Attribute
     */
    accept?: string;
    /**
     * @description 上传文件之前的钩子，参数为上传的文件，若返回 false 则停止上传。支持返回一个 Promise 对象，Promise 对象 reject 时则停止上传，resolve 时开始上传（ resolve 传入 File 或 Blob 对象则上传 resolve 传入对象）；也可以返回 Upload.LIST_IGNORE，此时列表中将不展示此文件。 注意：IE9 不支持该方法
     */
    beforeUpload?: (file: RcFile, FileList: RcFile[]) => boolean | {} | Promise<void | Blob | File>;
    /**
     * @description 上传文件改变时的状态
     */
    onChange?: (info: UploadChangeParam) => void;
    /**
     * @description 上传列表的内建样式，支持两种基本样式 text(上传附件) 和 picture（上传图片）
     */
    listType?: UploadListType;
    /**
     * @description 自定义类名
     */
    className?: string;
    /**
     * @description 点击文件链接或预览图标时的回调
     */
    onPreview?: (file: UploadFile<T>) => void;
    /**
     * @description 点击移除文件时的回调，返回值为 false 时不移除。支持返回一个 Promise 对象，Promise 对象 resolve(false) 或 reject 时不移除
     */
    onRemove?: (file: UploadFile<T>) => void | boolean | Promise<void | boolean>;
    /**
     * @description 自定义样式
     */
    style?: React.CSSProperties;
    /**
     * @description 是否禁用
     */
    disabled?: boolean;
    /**
     * @description 设置类名前缀
     */
    prefixCls?: string;
    /**
     * @description 自定义 text 样式下的预览按钮的文案
     */
    previewContent?: string | React.ReactNode;
    /**
     * @description 	通过覆盖默认的上传行为，可以自定义自己的上传实现
     */
    customRequest?: (options: RcCustomRequestOptions) => void;
    /**
     * @description 上传请求时是否携带 cookie
     */
    withCredentials?: boolean;
    /**
     * @description 是否点击打开文件对话框
     */
    openFileDialogOnClick?: boolean;
    /**
     * @description 唯一标识
     */
    id?: string;
    /**
     * @description 自定义文件预览逻辑
     */
    previewFile?: PreviewFileHandler;
    /** @deprecated Please use `beforeUpload` directly */
    transformFile?: TransformFileHandler;
    /**
     * @description ‘text’样式下自定义文件图标的渲染
     */
    iconRender?: (file: UploadFile<T>, listType?: UploadListType) => React.ReactNode;
    /**
     * @description 自定义缩略图是否使用 <img /> 标签进行显示
     */
    isImageUrl?: (file: UploadFile) => boolean;
    /**
     * @description 自定义上传列表项
     */
    itemRender?: ItemRender<T>;
    /**
     * @description 限制上传数量。当为 1 时，始终用最新上传的文件代替当前文件
     */
    maxCount?: number;
    /**
     * @description 自定义显示
     */
    extraRender?: (file: UploadFile<T>, listType?: UploadListType) => React.ReactNode;
    /**
     * @description 上传文件限制描述，仅在桌面端展示
     */
    uploadLabel?: string;
    /**
     * @description 上传按钮文案，仅在桌面端展示
     */
    uploadBtnLabel?: string;
    /**
     * @description 上传失败的文案
     */
    uploadErrorLabel?: string;
}
export interface UploadState<T = any> {
    fileList: UploadFile<T>[];
    dragState: string;
}
export interface UploadListProps<T = any> {
    listType?: UploadListType;
    onPreview?: (file: UploadFile<T>) => void;
    onRemove?: (file: UploadFile<T>) => void | boolean;
    items?: Array<UploadFile<T>>;
    prefixCls?: string;
    showRemoveIcon?: boolean;
    showPreviewIcon?: boolean;
    previewContent?: string | React.ReactNode;
    removeIcon?: React.ReactNode | ((file: UploadFile) => React.ReactNode);
    previewFile?: PreviewFileHandler;
    iconRender?: (file: UploadFile<T>, listType?: UploadListType) => React.ReactNode;
    isImageUrl?: (file: UploadFile) => boolean;
    appendAction?: React.ReactNode;
    itemRender?: ItemRender<T>;
    extraRender?: (file: UploadFile<T>, listType?: UploadListType) => React.ReactNode;
    isError: boolean;
    uploadErrorLabel?: string;
    extra?: React.ReactNode;
}
export {};
